pub struct PlatformReport {
pub os: String,
pub arch: String,
pub desktop_session: Option<String>,
pub xdg_session_type: Option<String>,
pub xdg_current_desktop: Option<String>,
pub wayland_display: Option<String>,
pub display: Option<String>,
pub xauthority: Option<String>,
pub dbus_session_bus_address: Option<String>,
pub xdg_runtime_dir: Option<String>,
pub gnome_shell_version: Check,
pub gnome_screenshot: Check,
}Fields
os: Stringarch: Stringdesktop_session: Option<String>xdg_session_type: Option<String>xdg_current_desktop: Option<String>wayland_display: Option<String>display: Option<String>dbus_session_bus_address: Option<String>xdg_runtime_dir: Option<String>gnome_shell_version: Checkgnome_screenshot: CheckTrait Implementations
Sourceimpl Clone for PlatformReport
impl Clone for PlatformReport
Sourcefn clone(&self) -> PlatformReport
fn clone(&self) -> PlatformReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PlatformReport
impl Debug for PlatformReport
Sourceimpl JsonSchema for PlatformReport
impl JsonSchema for PlatformReport
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PlatformReport
impl RefUnwindSafe for PlatformReport
impl Send for PlatformReport
impl Sync for PlatformReport
impl Unpin for PlatformReport
impl UnsafeUnpin for PlatformReport
impl UnwindSafe for PlatformReport