pub struct ReadinessReport {
pub can_register_mcp_tools: bool,
pub can_build_accessibility_tree: bool,
pub can_query_windows: bool,
pub can_focus_apps: bool,
pub can_focus_windows: bool,
pub can_send_development_input: bool,
pub recommended_next_step: String,
pub blockers: Vec<String>,
}Fields
can_register_mcp_tools: boolcan_build_accessibility_tree: boolcan_query_windows: boolcan_focus_apps: boolcan_focus_windows: boolcan_send_development_input: boolrecommended_next_step: Stringblockers: Vec<String>Trait Implementations
Sourceimpl Clone for ReadinessReport
impl Clone for ReadinessReport
Sourcefn clone(&self) -> ReadinessReport
fn clone(&self) -> ReadinessReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReadinessReport
impl Debug for ReadinessReport
Sourceimpl JsonSchema for ReadinessReport
impl JsonSchema for ReadinessReport
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ReadinessReport
impl RefUnwindSafe for ReadinessReport
impl Send for ReadinessReport
impl Sync for ReadinessReport
impl Unpin for ReadinessReport
impl UnsafeUnpin for ReadinessReport
impl UnwindSafe for ReadinessReport